<?php

/**
*
* @package phpbb3-SuperKniffel
* @version 1.2.0
* @author 2009 Bierhasser http://www.phpbb.de/community/memberlist.php?mode=viewprofile&u=3383
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/
/**
* @ignore
*/
define('IN_PHPBB', true);
$phpbb_root_path = '../';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.'.$phpEx);
include($phpbb_root_path . 'includes/db/db_tools.' . $phpEx);


// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup();

$my_dir = basename(dirname(__FILE__));
define ( 'EXTRACONF', $phpbb_root_path . 'includes/conf_superkniffel.' . $phpEx);

// Load language and custom template-path
$user->add_lang('mods/lang_superkniffel');
$user->add_lang('mods/info_superkniffel');
$template->set_custom_template('style', $my_dir);
$template->assign_var('T_TEMPLATE_PATH', 'style');


$new_mod_version = '1.2.0';
$prev_versions = array('1.0.x', '1.1.0');
$page_title = $user->lang['PLAY'] . ' ' .sprintf($user->lang['TITLE'], $new_mod_version);

$mode = request_var('mode', 'else');
$version = request_var('version', '0.0.0');
$confirm = request_var('confirm', 0);

if ($user->data['user_type'] != USER_FOUNDER)
{
	$template->assign_var('T_TEMPLATE_PATH', $phpbb_root_path . 'styles/' . $user->theme['template_path'] . '/template');
	trigger_error($user->lang['NEED_FOUNDER'], E_USER_ERROR);
}

page_header($page_title);
$error = false;
$show_upd_menue = $show_ins_menue = $show_rem_menue = true;
if ( !defined('KNIFFEL_HIGSCORE_TABLE') )
{
	install_error($user->lang['ERR_HIGSCORE_TABLE']);
}
if ( !defined('KNIFFEL_USER_TABLE') )
{
	install_error($user->lang['ERR_USER_TABLE']);
}
if ( !defined('KNIFFEL_WURF_TABLE') )
{
	install_error($user->lang['ERR_WURF_TABLE']);
}

// What sql_layer should we use?
switch ($db->sql_layer)
{
	case 'mysql':
		$db_schema = 'mysql_40';
		$delimiter = ';';
	break;

	case 'mysql4':
		if (version_compare($db->mysql_version, '4.1.3', '>='))
		{
			$db_schema = 'mysql_41';
		}
		else
		{
			$db_schema = 'mysql_40';
		}
		$delimiter = ';';
	break;

	case 'mysqli':
		$db_schema = 'mysql_41';
		$delimiter = ';';
	break;

	case 'mssql':
		$db_schema = 'mssql';
		$delimiter = 'GO';
	break;

	case 'postgres':
		$db_schema = 'postgres';
		$delimiter = ';';
	break;

	case 'sqlite':
		$db_schema = 'sqlite';
		$delimiter = ';';
	break;

	case 'firebird':
		$db_schema = 'firebird';
		$delimiter = ';;';
	break;

	case 'oracle':
		$db_schema = 'oracle';
		$delimiter = '/';
	break;

	default:
		install_error('Sorry, unsupportet Databases found.');
	break;
}

switch ($mode)
{
	case 'install':
		if ($confirm)
		{
			// prüfe ob Tabellen schon existieren
			include($phpbb_root_path . 'includes/functions_install.' . $phpEx);
			$tables = get_tables($db);
			foreach ($tables as $table_name)
			{
				if (in_array($table_name, array(KNIFFEL_HIGSCORE_TABLE, KNIFFEL_USER_TABLE, KNIFFEL_WURF_TABLE)))
				{
					$error[] = sprintf($user->lang['ERR_TB_EXISTS'], $table_name);
				}
			}
			if ($error)
			{
				install_error($error);
			}
			// locate the schema files
			$dbms_schema = 'schemas/_' . $db_schema . '_schema.sql';
			$sql_query = @file_get_contents($dbms_schema);
			$sql_query = preg_replace('#phpbb_#i', $table_prefix, $sql_query);
			$sql_query = preg_replace('/\n{2,}/', "\n", preg_replace('/^#.*$/m', "\n", $sql_query));
			$sql_query = split_sql_file($sql_query, $delimiter);
			// make the new one's
			foreach ($sql_query as $sql)
			{
				if (!$db->sql_query($sql))
				{
					$error = $db->sql_error();
					$this->p_master->db_error($error['message'], $sql, __LINE__, __FILE__);
				}
			}
			unset($sql_query);

			// clear cache and log what we did
			$cache->purge();
			add_log('admin', 'LOG_INSTALL_INSTALLED', sprintf($user->lang['INS_SUCCESS'], $user->lang['PLAY'] . ' ' . $new_mod_version));
			add_log('admin', 'LOG_PURGE_CACHE');

			$template->assign_vars(array(
				'L_WELCOME'		=> sprintf($user->lang['INS_SUCCESS'], $user->lang['PLAY'] . ' ' . $new_mod_version),
				'S_INFORMATION'		=> sprintf($user->lang['INS_SUCC_NOTE'], $phpbb_root_path . $my_dir),
			));
		}
		$show_upd_menue = false;
		$show_rem_menue = false;
		$template->assign_vars(array(
			'S_INS_ACTIV'	=> true,
			'S_NOT_INTRO'	=> true,
			'L_NOTE'	=> (!$confirm) ? sprintf($user->lang['INS_NOTE'], $user->lang['PLAY'] . ' ' . $new_mod_version) : false,
			'L_LEGEND'	=> $user->lang['INS_MENU'] . ' ' . $new_mod_version,
			'L_LABLE'	=> sprintf($user->lang['NOTE_INST'], $user->lang['PLAY'] . ' ' . $new_mod_version),
			'S_ACTION'	=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=install'),
		));
	break;
	case 'remove':
		if ($confirm)
		{
			// prüfe ob Tabellen schon existieren
			include($phpbb_root_path . 'includes/functions_install.' . $phpEx);
			$tables = get_tables($db);
			foreach ($tables as $table_name)
			{
				if (in_array($table_name, array(KNIFFEL_HIGSCORE_TABLE, KNIFFEL_USER_TABLE, KNIFFEL_WURF_TABLE)))
				{
					// Drop thes tables if existing
					$phpbb_db_tools->sql_table_drop($table_name);
				}
			}

			if ( @file_exists(EXTRACONF) and @is_writable(EXTRACONF) )
			{
				@unlink(EXTRACONF);
			}

			$cache->purge();
			add_log('admin', $user->lang['REM_SUCCESS']);
			add_log('admin', 'LOG_PURGE_CACHE');
			$template->assign_vars(array(
				'L_WELCOME'		=> $user->lang['REM_SUCCESS'],
				'S_INFORMATION'		=> sprintf($user->lang['REM_NOTE'], $phpbb_root_path . $my_dir),
			));
		}
		$show_upd_menue = false;
		$show_ins_menue = false;
		$template->assign_vars(array(
			'S_REM_ACTIV'	=> true,
			'S_NOT_INTRO'	=> true,
			'L_LEGEND'	=> $user->lang['REMOVE'],
			'L_LABLE'	=> $user->lang['REM_SHURE'], $user->lang['PLAY'],
			'S_ACTION'	=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=remove'),
		));
	break;
	case 'update':
		if ($confirm)
		{
			// Use phpBB-Stuff
			$phpbb_db_tools = new phpbb_db_tools($db);
			// prüfe ob Tabellen schon existieren
			include($phpbb_root_path . 'includes/functions_install.' . $phpEx);
			$tables = get_tables($db);
			$wurf_table = $highscore_table = $user_table = false;
			foreach ($tables as $table_name)
			{
				if ($table_name == KNIFFEL_HIGSCORE_TABLE or $table_name == KNIFFEL_HIGSCORE_TABLE.'_tmp')
				{
					$highscore_table = true;
				}
				if ($table_name == KNIFFEL_USER_TABLE or $table_name == KNIFFEL_USER_TABLE.'_tmp')
				{
					$user_table = true;
				}
				if ($table_name == KNIFFEL_WURF_TABLE or $table_name == KNIFFEL_WURF_TABLE.'_tmp')
				{
					$wurf_table = true;
				}
			}
			if (!$user_table || !$wurf_table || !$highscore_table)
			{
				install_error($user->lang['ERR_TB_NOT_EXISTS']);
			}
			switch ($version)
			{
				case '1.0.x':
					$schema_changes = array();
					if ($phpbb_db_tools->sql_column_exists(KNIFFEL_WURF_TABLE, 'anzeige'))
					{
						$phpbb_db_tools->sql_column_remove(KNIFFEL_WURF_TABLE, 'anzeige');
					}
					if ($phpbb_db_tools->sql_column_exists(KNIFFEL_USER_TABLE, 'neu'))
					{
						$phpbb_db_tools->sql_column_remove(KNIFFEL_USER_TABLE, 'neu');
					}
					// Alle alten Tabellen umbenennen
					$db->sql_query('RENAME TABLE ' . KNIFFEL_WURF_TABLE . ' TO ' . KNIFFEL_WURF_TABLE . '_tmp');
					$db->sql_query('RENAME TABLE ' . KNIFFEL_USER_TABLE . ' TO ' . KNIFFEL_USER_TABLE . '_tmp');
					$db->sql_query('RENAME TABLE ' . KNIFFEL_HIGSCORE_TABLE . ' TO ' . KNIFFEL_HIGSCORE_TABLE . '_tmp');

					// Neue Tabellen erstellen
					$dbms_schema = 'schemas/_' . $db_schema . '_schema.sql';
					$sql_query = @file_get_contents($dbms_schema);
					$sql_query = preg_replace('#phpbb_#i', $table_prefix, $sql_query);
					$sql_query = preg_replace('/\n{2,}/', "\n", preg_replace('/^#.*$/m', "\n", $sql_query));
					$sql_query = split_sql_file($sql_query, $delimiter);
					// make the new one's
					foreach ($sql_query as $sql)
					{
						if (!$db->sql_query($sql))
						{
							$error = $db->sql_error();
							$this->p_master->db_error($error['message'], $sql, __LINE__, __FILE__);
						}
					}
					unset($sql_query);

					// Higescore auslesen und in neue Tabelle schreiben
					$Higscore_games = false;
					if ($phpbb_db_tools->sql_column_exists(KNIFFEL_HIGSCORE_TABLE.'_tmp', 'games'))
					{
						$Higscore_games = 'games';
					}
					$games = ($Higscore_games) ? ', games' : '';
					$sql = 'SELECT userid, score_date, points'.$games.'
						FROM ' . KNIFFEL_HIGSCORE_TABLE . '_tmp
						ORDER BY score_date, points DESC';
					$sql1 = $db->sql_query($sql);
					$score_count = 0;
					$score = array();

					while ($row = $db->sql_fetchrow($sql1))
					{
						$score_count++;
						$h_monat = date('m', $row['score_date']);
						$h_jahr = date('Y', $row['score_date']);
						$row['games'] = (intval($row['games']) > 0) ? (int) $row['games'] : 1;
						$score[$h_jahr][$h_monat][$row['userid']] = array($row['points'], $row['score_date'], $row['games']);
						if ($score[$h_jahr][$h_monat][$row['userid']][0] < $row['points'] )
						{
							$score[$h_jahr][$h_monat][$row['userid']] = array($row['points'], $row['score_date'], $row['games']);
						}
					}
					$db->sql_freeresult($sql);

					$OUT = '';
					foreach ($score as $jahr => $res1)
					{
						foreach ($res1 as $monat => $res2)
						{
							foreach ($res2 as $userid => $rest)
							{
							$OUT .= "('$userid', '$monat', '$jahr', '".$rest[1]."', '".$rest[0]."', '".$rest[2]."', '0'),\n";
							}
						}
					}
					if (strlen($OUT) > 0)
					{
						$OUT = substr($OUT, 0, -2).';';
						$db->sql_query('INSERT INTO '.KNIFFEL_HIGSCORE_TABLE.' (userid, monat, jahr, score_date, points, games, score_array) VALUES '.$OUT);
					}
					$sql = 'DROP TABLE IF EXISTS ' . KNIFFEL_HIGSCORE_TABLE.'_tmp';
					$result = $db->sql_query($sql);
					$db->sql_freeresult($result);

					// user auslesen
					$felder = array('userid', 'wurf', 'wurfel1', 'wurfel2', 'wurfel3', 'wurfel4', 'wurfel5', 'wurfel6', 'zaehler', 'einer', 'zweier', 'dreier', 'vierer', 'funfer', 'sechser', 'dpasch', 'vpasch', 'fpasch', 'dopasch', 'trpasch', 'crpasch', 'gpasch', 'upasch', 'fullh', 'kstra', 'gstra', 'allee', 'kniffel', 'chance', 'bonus', 'zsumm1', 'zsumm2', 'c1', 'c2', 'c3', 'c4', 'c5', 'c6');
					if ($phpbb_db_tools->sql_column_exists(KNIFFEL_USER_TABLE.'_tmp', 'games'))
					{
						array_push($felder, 'games');
					}
					$c = count($felder);
					$sql = 'SELECT '.implode(', ', $felder).'
						FROM ' . KNIFFEL_USER_TABLE . '_tmp';
					$sql1 = $db->sql_query($sql);
					$OUT = '';
					while ($row = $db->sql_fetchrow($sql1))
					{
						$OUT .= '(';
						$st = $c - 1;
						for ($i =0; $i < $c; $i++)
						{
							$OUT .= "'".intval($row[$felder[$i]])."'";
							$OUT .= ($i < $st ) ? ', ' : '';
						}
						$OUT .= '),';
					}
					$db->sql_freeresult($sql);
					if (strlen($OUT) > 0)
					{
						$OUT = substr($OUT, 0, -1).';';
						$db->sql_query('INSERT INTO '.KNIFFEL_USER_TABLE.' ('.implode(', ', $felder).') VALUES '.$OUT);
					}
					$sql = 'DROP TABLE IF EXISTS ' . KNIFFEL_USER_TABLE.'_tmp';
					$result = $db->sql_query($sql);
					$db->sql_freeresult($result);

					// wurf auslesen
					$felder = array('userid', 'einer', 'zweier', 'dreier', 'vierer', 'funfer', 'sechser', 'dpasch', 'vpasch', 'fpasch', 'dopasch', 'trpasch', 'crpasch', 'gpasch', 'upasch', 'fullh', 'kstra', 'gstra', 'allee', 'kniffel', 'chance');
					$c = count($felder);
					$sql = 'SELECT '.implode(', ', $felder).'
						FROM ' . KNIFFEL_WURF_TABLE . '_tmp';
					$sql1 = $db->sql_query($sql);
					$OUT = '';
					while ($row = $db->sql_fetchrow($sql1))
					{
						$OUT .= '(';
						$st = $c - 1;
						for ($i = 0; $i < $c; $i++)
						{
							$OUT .= "'".$row[$felder[$i]]."'";
							$OUT .= ($i < $st ) ? ', ' : '';
						}
						$OUT .= '),';
					}
					$db->sql_freeresult($sql);
					if (strlen($OUT) > 0)
					{
						$OUT = substr($OUT, 0, -1).';';
						$db->sql_query('INSERT INTO '.KNIFFEL_WURF_TABLE.' ('.implode(', ', $felder).') VALUES '.$OUT);
					}
					$sql = 'DROP TABLE IF EXISTS ' . KNIFFEL_WURF_TABLE.'_tmp';
					$result = $db->sql_query($sql);
					$db->sql_freeresult($result);
				break;
				case '1.1.0':

				break;
				default:
					$error[] = $user->lang['ERR_UNGOWN_UPD'];
				break;
			}

			if ($error)
			{
				install_error($error);
			}

			$cache->purge();
			add_log('admin', $user->lang['PLAY'], sprintf($user->lang['UPD_VERSION'], $version, $new_mod_version));
			add_log('admin', 'LOG_PURGE_CACHE');

			$template->assign_vars(array(
				'L_WELCOME'		=> $user->lang['PLAY'] . sprintf($user->lang['UPD_SUCCESS'], $version, $new_mod_version),
				'S_INFORMATION'		=> sprintf($user->lang['UPD_SUCC_NOTE'], $phpbb_root_path . $my_dir),
			));
		}
		$show_ins_menue = false;
		$show_rem_menue = false;
		$note = str_replace('.', '', $version);
		$template->assign_vars(array(
			'S_NOT_INTRO'	=> true,
			'S_UPDATE'	=> $version,
			'L_LEGEND'	=> sprintf($user->lang['UPD_VERSION'], $version, $new_mod_version),
			'L_NOTE'	=> (!$confirm) ? $user->lang['NOTE_'.$note] : false,
			'L_LABLE'	=> $user->lang['NOTE_UPD'],
			'S_ACTION'	=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=update&amp;version=' . $version),
		));
	break;
	default:
		$template->assign_vars(array(
			'S_INTRO'	=> true,
			'L_NOTE'	=> $user->lang['WELCOME_NOTE'],
		));
	break;
}


for ($i = 0; $i < count($prev_versions); $i++)
{
	$template->assign_block_vars('update_version', array(
		'FROM_TO'	=> sprintf($user->lang['UPD_VERSION'], $prev_versions[$i], $new_mod_version),
		'U_LINK'	=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=update&amp;version='.$prev_versions[$i]),
		'S_UPD_AKTIV'	=> ($mode == 'update' && $version == $prev_versions[$i]) ? true: false,
	));
}
$template->assign_vars(array(
	'L_PAGE_TITLE'		=> $page_title,
	'S_UPDATE_MENUE'	=> $show_upd_menue,
	'S_INSTALL_MENUE'	=> $show_ins_menue,
	'S_REMOVE_MENUE'	=> $show_rem_menue,
	'S_VERSION'		=> $new_mod_version,
	'U_INTRO'		=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx"),
	'U_INSTALL'		=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=install'),
	'U_REM'			=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx", 'mode=remove'),
));



$template->set_filenames(array(
	'body' => 'install_body.html')
);

page_footer();

function install_error($text)
{
	global $phpbb_root_path, $my_dir, $phpEx, $user, $template;
	if (is_array($text))
	{
		$text = implode("<br />\n",$text);
	}
	$template->assign_vars(array(
		'S_WARNING'		=> $text,
		'L_WELCOME'		=> $user->lang['WARNING'],
		'L_NOTE'		=> $user->lang['ERR_MAIN'],
		'L_PAGE_TITLE'	=> 'FATAL ERROR',
		'U_INTRO'		=> append_sid("{$phpbb_root_path}{$my_dir}/index.$phpEx"),
	));

	$template->set_filenames(array(
	'body' => 'install_body.html')
	);

	page_footer();
}
?>