/*

 $Id: $

*/

BEGIN;

/*
	Domain definition
*/
CREATE DOMAIN varchar_ci AS varchar(255) NOT NULL DEFAULT ''::character varying;

/*
	Operation Functions
*/
CREATE FUNCTION _varchar_ci_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) = LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_not_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) != LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) < LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) <= LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) > LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_equals(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) >= LOWER($2)' LANGUAGE SQL STRICT;

/*
	Operators
*/
CREATE OPERATOR <(
  PROCEDURE = _varchar_ci_less_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >,
  NEGATOR = >=,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR <=(
  PROCEDURE = _varchar_ci_less_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >=,
  NEGATOR = >,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR >(
  PROCEDURE = _varchar_ci_greater_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <,
  NEGATOR = <=,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR >=(
  PROCEDURE = _varchar_ci_greater_equals,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <=,
  NEGATOR = <,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR <>(
  PROCEDURE = _varchar_ci_not_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <>,
  NEGATOR = =,
  RESTRICT = neqsel,
  JOIN = neqjoinsel);

CREATE OPERATOR =(
  PROCEDURE = _varchar_ci_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = =,
  NEGATOR = <>,
  RESTRICT = eqsel,
  JOIN = eqjoinsel,
  HASHES,
  MERGES,
  SORT1= <);

/*
	Table: 'phpbb_kniffel_highscore'
*/
CREATE SEQUENCE phpbb_kniffel_highscore_seq;

CREATE TABLE phpbb_kniffel_highscore (
	nr INT4 DEFAULT nextval('phpbb_kniffel_highscore_seq'),
	userid INT4 DEFAULT '0' NOT NULL CHECK (userid >= 0),
	monat INT2 DEFAULT '0' NOT NULL CHECK (monat >= 0),
	jahr INT2 DEFAULT '0' NOT NULL CHECK (jahr >= 0),
	score_date INT4 DEFAULT '0' NOT NULL CHECK (score_date >= 0),
	points INT4 DEFAULT '0' NOT NULL CHECK (points >= 0),
	games INT4 DEFAULT '1' NOT NULL CHECK (games >= 0),
	score_array varchar(4000) NOT NULL,
	PRIMARY KEY (nr)
);

CREATE INDEX phpbb_kniffel_highscore_monat ON phpbb_kniffel_highscore (points,score_date);
CREATE INDEX phpbb_kniffel_highscore_jahr ON phpbb_kniffel_highscore (jahr);

/*
	Table: 'phpbb_kniffel_wurf'
*/
CREATE TABLE phpbb_kniffel_wurf (
	userid INT4 DEFAULT '0' NOT NULL CHECK (userid >= 0),
	einer char(6) DEFAULT '0' NOT NULL,
	zweier char(6) DEFAULT '0' NOT NULL,
	dreier char(6) DEFAULT '0' NOT NULL,
	vierer char(6) DEFAULT '0' NOT NULL,
	funfer char(6) DEFAULT '0' NOT NULL,
	sechser char(6) DEFAULT '0' NOT NULL,
	dpasch char(6) DEFAULT '0' NOT NULL,
	vpasch char(6) DEFAULT '0' NOT NULL,
	fpasch char(6) DEFAULT '0' NOT NULL,
	dopasch char(6) DEFAULT '0' NOT NULL,
	trpasch char(6) DEFAULT '0' NOT NULL,
	crpasch char(6) DEFAULT '0' NOT NULL,
	gpasch char(6) DEFAULT '0' NOT NULL,
	upasch char(6) DEFAULT '0' NOT NULL,
	fullh char(6) DEFAULT '0' NOT NULL,
	kstra char(6) DEFAULT '0' NOT NULL,
	gstra char(6) DEFAULT '0' NOT NULL,
	allee char(6) DEFAULT '0' NOT NULL,
	kniffel char(6) DEFAULT '0' NOT NULL,
	chance char(6) DEFAULT '0' NOT NULL,
	PRIMARY KEY (userid)
);


/*
	Table: 'phpbb_kniffel_user'
*/
CREATE TABLE phpbb_kniffel_user (
	userid INT4 DEFAULT '0' NOT NULL CHECK (userid >= 0),
	wurf INT2 DEFAULT '0' NOT NULL CHECK (wurf >= 0),
	wurfel1 INT2 DEFAULT '0' NOT NULL CHECK (wurfel1 >= 0),
	wurfel2 INT2 DEFAULT '0' NOT NULL CHECK (wurfel2 >= 0),
	wurfel3 INT2 DEFAULT '0' NOT NULL CHECK (wurfel3 >= 0),
	wurfel4 INT2 DEFAULT '0' NOT NULL CHECK (wurfel4 >= 0),
	wurfel5 INT2 DEFAULT '0' NOT NULL CHECK (wurfel5 >= 0),
	wurfel6 INT2 DEFAULT '0' NOT NULL CHECK (wurfel6 >= 0),
	zaehler INT2 DEFAULT '0' NOT NULL CHECK (zaehler >= 0),
	einer INT2 DEFAULT '99' NOT NULL CHECK (einer >= 0),
	zweier INT2 DEFAULT '99' NOT NULL CHECK (zweier >= 0),
	dreier INT2 DEFAULT '99' NOT NULL CHECK (dreier >= 0),
	vierer INT2 DEFAULT '99' NOT NULL CHECK (vierer >= 0),
	funfer INT2 DEFAULT '99' NOT NULL CHECK (funfer >= 0),
	sechser INT2 DEFAULT '99' NOT NULL CHECK (sechser >= 0),
	dpasch INT2 DEFAULT '99' NOT NULL CHECK (dpasch >= 0),
	vpasch INT2 DEFAULT '99' NOT NULL CHECK (vpasch >= 0),
	fpasch INT2 DEFAULT '99' NOT NULL CHECK (fpasch >= 0),
	dopasch INT2 DEFAULT '99' NOT NULL CHECK (dopasch >= 0),
	trpasch INT2 DEFAULT '99' NOT NULL CHECK (trpasch >= 0),
	crpasch INT2 DEFAULT '99' NOT NULL CHECK (crpasch >= 0),
	gpasch INT2 DEFAULT '99' NOT NULL CHECK (gpasch >= 0),
	upasch INT2 DEFAULT '99' NOT NULL CHECK (upasch >= 0),
	fullh INT2 DEFAULT '99' NOT NULL CHECK (fullh >= 0),
	kstra INT2 DEFAULT '99' NOT NULL CHECK (kstra >= 0),
	gstra INT2 DEFAULT '99' NOT NULL CHECK (gstra >= 0),
	allee INT2 DEFAULT '99' NOT NULL CHECK (allee >= 0),
	kniffel INT2 DEFAULT '99' NOT NULL CHECK (kniffel >= 0),
	chance INT2 DEFAULT '99' NOT NULL CHECK (chance >= 0),
	bonus INT2 DEFAULT '0' NOT NULL CHECK (bonus >= 0),
	zsumm1 INT2 DEFAULT '0' NOT NULL CHECK (zsumm1 >= 0),
	zsumm2 INT2 DEFAULT '0' NOT NULL CHECK (zsumm2 >= 0),
	games INT4 DEFAULT '1' NOT NULL CHECK (games >= 0),
	c1 INT2 DEFAULT '0' NOT NULL CHECK (c1 >= 0),
	c2 INT2 DEFAULT '0' NOT NULL CHECK (c2 >= 0),
	c3 INT2 DEFAULT '0' NOT NULL CHECK (c3 >= 0),
	c4 INT2 DEFAULT '0' NOT NULL CHECK (c4 >= 0),
	c5 INT2 DEFAULT '0' NOT NULL CHECK (c5 >= 0),
	c6 INT2 DEFAULT '0' NOT NULL CHECK (c6 >= 0),
	PRIMARY KEY (userid)
);



COMMIT;